@@ -13,11 +13,14 @@
 #include "specials.h"
 
 #include <qcursor.h>
+//Added by qt3to4:
+#include <QLabel>
+#include <QFrame>
 
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <klocale.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kommanderplugin.h>
 
 #define INSERTMENUITEM 100
@@ -33,15 +36,16 @@
 #define LAST_FUNCTION INSERTSUBMENU 
 
 PopupMenu::PopupMenu(QWidget *parent, const char *name)
- : QLabel(parent, name), KommanderWidget(this)
+ : QLabel(parent), KommanderWidget(this)
 {
+  setObjectName(name);
   QStringList states;
   states << "default";
   setStates(states);
   setDisplayStates(states);
   if (KommanderWidget::inEditor)
   {
-    setPixmap(KGlobal::iconLoader()->loadIcon("contents", KIcon::NoGroup, KIcon::SizeMedium));
+    setPixmap(KIconLoader::global()->loadIcon("contents", KIconLoader::NoGroup, KIconLoader::SizeMedium));
     setFrameStyle(QFrame::Box | QFrame::Plain);
     setLineWidth(1);
     setFixedSize(pixmap()->size());
@@ -49,10 +53,9 @@ PopupMenu::PopupMenu(QWidget *parent, const char *name)
   else
     setHidden(true);
 
-  m_menu = new KPopupMenu(this);
+  m_menu = new KMenu(this);
   connect(m_menu, SIGNAL(activated(int)), this, SLOT(slotMenuItemActivated(int)));
-
-  KommanderPlugin::setDefaultGroup(Group::DCOP);
+  KommanderPlugin::setDefaultGroup(Group::DBUS);
   KommanderPlugin::registerFunction(INSERTMENUITEM, "insertMenuItem(QString widget, QString text, QString executeWidget, int index, QString icon)",  i18n("Insert an item into the popup menu. The executeWidget's execute method will be run when this item is selected. Returns the id of the inserted item. Use -1 for index to insert to the end. The icon is optional."), 4, 5);
   KommanderPlugin::registerFunction(INSERTSEPARATOR, "insertSeparator(QString widget, int index)",  i18n("Insert a separator item into the popup menu. Use -1 for index to insert to the end."), 2);
   KommanderPlugin::registerFunction(CHANGEMENUITEM, "changeMenuItem(QString widget, int id, QString text, QString executeWidget, QString icon)",  i18n("Change an item specified by id in the popup menu. The executeWidget's execute method will be run when this item is selected."), 4, 5);
@@ -62,7 +65,7 @@ PopupMenu::PopupMenu(QWidget *parent, const char *name)
   KommanderPlugin::registerFunction(SETITEMCHECKED, "setItemChecked(QString widget, int id, bool enable)",  i18n("Apply checked status for the item specified by id."), 3);
   KommanderPlugin::registerFunction(ITEMVISIBLE, "itemVisible(QString widget, int id)",  i18n("Check if the item specified by id is visible."), 2);
   KommanderPlugin::registerFunction(ITEMCHECKED, "itemChecked(QString widget, int id)",  i18n("Verify if the item specified by id is checked."), 2);
-  KommanderPlugin::registerFunction(INSERTSUBMENU, "insertSubmenu(QString widget, QString text, QString menuWidget, int index, QString icon)",  i18n("Insert submenu widget into the popup menu. Use -1 for index to insert to the end. The icon is optional."), 4, 5);
+  KommanderPlugin::registerFunction(INSERTSUBMENU, "insertSubmenu(QString widget, QString text, QString menuWidget, int index, QString icon)",  i18n("Insert submenu widget into the popup menu. Use -1 for index to insert to the end. The icon is optional."), 4, 5); 
 }
 
 
@@ -93,7 +96,7 @@ void PopupMenu::setAssociatedText(const QStringList& a_at)
 
 void PopupMenu::setWidgetText(const QString& a_text)
 {
-  KommanderWidget::setAssociatedText(a_text);
+  KommanderWidget::setAssociatedText(QStringList(a_text));
 }
 
 void PopupMenu::setPopulationText(const QString& a_text)
@@ -119,7 +122,7 @@ void PopupMenu::slotMenuItemActivated(int id)
 
 void PopupMenu::populate()
 {
-  setAssociatedText(KommanderWidget::evalAssociatedText( populationText()));
+  setAssociatedText(QStringList(KommanderWidget::evalAssociatedText( populationText())));
 }
 
 QString PopupMenu::insertSubmenu(const QString& title, const QString &menuWidget, int index, const QString& icon)
@@ -130,7 +133,7 @@ QString PopupMenu::insertSubmenu(const QString& title, const QString &menuWidget
     if (icon.isEmpty())
      return QString::number(m_menu->insertItem(title, dynamic_cast<PopupMenu*>(w)->menu(), index));
     else
-     return QString::number( m_menu->insertItem(KGlobal::iconLoader()->loadIcon(icon, KIcon::NoGroup, KIcon::SizeMedium), title, dynamic_cast<PopupMenu*>(w)->menu(), index));
+     return QString::number( m_menu->insertItem(KIconLoader::global()->loadIcon(icon, KIconLoader::NoGroup, KIconLoader::SizeMedium), title, dynamic_cast<PopupMenu*>(w)->menu(), index));
   }
   return QString();
 }
@@ -138,17 +141,18 @@ QString PopupMenu::insertSubmenu(const QString& title, const QString &menuWidget
 
 bool PopupMenu::isFunctionSupported(int f)
 {
-  return f == DCOP::clear || f == DCOP::execute || f == DCOP::item || (f >= INSERTMENUITEM && f <= LAST_FUNCTION) || f == DCOP::count || f == DCOP::geometry;
+  return f == DBUS::clear || f == DBUS::execute || f == DBUS::item || (f >= INSERTMENUITEM && f <=
+          LAST_FUNCTION) || f == DBUS::count || f == DBUS::geometry;
 }
 
-QString PopupMenu::handleDCOP(int function, const QStringList& args)
+QString PopupMenu::handleDBUS(int function, const QStringList& args)
 {
   switch (function) {
-    case DCOP::clear:
+    case DBUS::clear:
       m_menu->clear();
       m_associations.clear();
       break;
-    case DCOP::execute:
+    case DBUS::execute:
       m_params = args;
       evalAssociatedText();
       break;
@@ -156,10 +160,10 @@ QString PopupMenu::handleDCOP(int function, const QStringList& args)
     {
       uint index = args[2].toInt();
       int id = -1;
-      if (args[3].isEmpty())
+      if (args.size() < 4 || (args.size() > 3 && args[3].isEmpty()))
         id = m_menu->insertItem(args[0], index);
       else
-        id = m_menu->insertItem(KGlobal::iconLoader()->loadIcon(args[3], KIcon::NoGroup, KIcon::SizeMedium), args[0], index);
+        id = m_menu->insertItem(KIconLoader::global()->loadIcon(args[3], KIconLoader::NoGroup, KIconLoader::SizeMedium), args[0], index);
       m_associations[id] = args[1];
       return QString::number(id);
       break;
@@ -175,14 +179,15 @@ QString PopupMenu::handleDCOP(int function, const QStringList& args)
       if (args[3].isEmpty())
         m_menu->changeItem(id, args[1]);
       else
-        m_menu->changeItem(id, KGlobal::iconLoader()->loadIcon(args[3], KIcon::NoGroup, KIcon::SizeMedium), args[1]);
+        m_menu->changeItem(id, KIconLoader::global()->loadIcon(args[3], KIconLoader::NoGroup, KIconLoader::SizeMedium), args[1]);
       m_associations[id] = args[2];
       break;
     }
     case INSERTSEPARATOR:
     {
       uint index = args[0].toInt();
-      m_menu->insertSeparator(index);     
+      m_menu->insertSeparator(index);    
+      break; 
     }
     case SETITEMENABLED:
     {
@@ -220,21 +225,21 @@ QString PopupMenu::handleDCOP(int function, const QStringList& args)
       return m_menu->isItemChecked(id) ? "1" : "0";
       break;
     }
-    case DCOP::item:
+    case DBUS::item:
     {
-      uint index = args[0].toInt();
+      int index = args[0].toInt();
       return index < m_params.count() ? m_params[index] : QString::null;
     }
-    case DCOP::count:
-      return QString::number(m_menu->count());
-    case DCOP::geometry:
+    case DBUS::count:
+      return QString::number(m_menu->actions().count());
+    case DBUS::geometry:
     {
       QString geo = QString::number(this->x())+" "+QString::number(this->y())+" "+QString::number(this->width())+" "+QString::number(this->height());
       return geo;
       break;
     }
     default:
-      return KommanderWidget::handleDCOP(function, args);
+      return KommanderWidget::handleDBUS(function, args);
   }
   return QString();
 }
