@@ -1,14 +1,28 @@
 
-/***************************************************************************
-                          breakpoint.c  -  breakpoint implementation
-                             -------------------
-    begin                : Fri Nov 2 2001
-    copyright            : (C) 2001 by Keith Isdale
-    email                : k_isdale@tpg.com.au
- ***************************************************************************/
+/**
+ *
+ *  This file is part of the kdewebdev package
+ *  Copyright (c) 2001 Keith Isdale <keith@kdewebdev.org>
+ *
+ *  This library is free software; you can redistribute it and/or 
+ *  modify it under the terms of the GNU General Public License as 
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
+ **/
+
 
-#include "xsldbg.h"
 #include "breakpoint.h"
+#include "xsldbg.h"
 #include "arraylist.h"
 #include "options.h"
 
@@ -18,44 +32,15 @@ extern int xsldbgValidateBreakpoints; /*located in debugXSL.c*/
        Private functions
 -----------------------------------------------------------*/
 
-/**
- * lineNoItemNew:
- * 
- * Returns a new hash table for break points
- */
 xmlHashTablePtr lineNoItemNew(void);
 
 
-/**
- * lineNoItemFree:
- * @item: valid hashtable of break points
- * 
- * Free @item and all its contents
- */
 void lineNoItemFree(void *item);
 
 
-/**
- * lineNoItemDelete:
- * @breakPointHash: Is valid
- * @breakPtr: Is valid
- * 
- * Returns 1 if able to delete @breakPtr from @breakPointHash,
- *         0 otherwise
- */
 int lineNoItemDelete(xmlHashTablePtr breakPointHash,
                      breakPointPtr breakPtr);
 
-/**
- * lineNoItemAdd:
- * @breakPointHash: is valid
- * @breakPtr: is valid
- *
- * Add breakpoint to hash 
- *
- * Returns 1 if able to add @breakPtr to @breakPointHash,
- *         0 otherwise
- */
 int lineNoItemAdd(xmlHashTablePtr breakPointHash, breakPointPtr breakPtr);
 
 /*-----------------------------------------------------------
@@ -77,11 +62,6 @@ int breakPointCounter = 0;
 breakPointPtr activeBreakPointItem = NULL;
 
 
-/**
- * lineNoItemNew:
- * 
- * Returns a new hash table for break points
- */
 xmlHashTablePtr
 lineNoItemNew(void)
 {
@@ -93,14 +73,7 @@ lineNoItemNew(void)
 }
 
 
-/**
- * lineNoItemFree:
- * @item: valid hashtable of break points
- * 
- * Free @item and all its contents
- */
-void
-lineNoItemFree(void *item)
+void lineNoItemFree(void *item)
 {
     xmlHashTablePtr hash = (xmlHashTablePtr) item;
 
@@ -117,16 +90,7 @@ lineNoItemFree(void *item)
 }
 
 
-/**
- * lineNoItemDelete:
- * @breakPointHash: is valid
- * @breakPtr: is valid
- * 
- * Returns 1 if able to delete @breakPtr from @breakPointHash,
- *         0 otherwise
- */
-int
-lineNoItemDelete(xmlHashTablePtr breakPointHash, breakPointPtr breakPtr)
+int lineNoItemDelete(xmlHashTablePtr breakPointHash, breakPointPtr breakPtr)
 {
     int result = 0;
 
@@ -149,16 +113,7 @@ lineNoItemDelete(xmlHashTablePtr breakPointHash, breakPointPtr breakPtr)
 }
 
 
-/**
- * lineNoItemAdd:
- * @breakPointHash: is valid
- * @breakPtr: is valid
- *
- * Returns 1 if able to add @breakPtr to @breakPointHash,
- *         0 otherwise
- */
-int
-lineNoItemAdd(xmlHashTablePtr breakPointHash, breakPointPtr breakPtr)
+int lineNoItemAdd(xmlHashTablePtr breakPointHash, breakPointPtr breakPtr)
 {
     int result = 0;
 
@@ -169,16 +124,7 @@ lineNoItemAdd(xmlHashTablePtr breakPointHash, breakPointPtr breakPtr)
     return result;
 }
 
-/**
- * breakPointGetLineNoHash:
- * @lineNo: Line number of of breakpoints of interest
- *
- * Return A hash of breakpoints with same line number
- *
- * Returns A hash of breakpoints with a line number of @lineNo
- */
-xmlHashTablePtr
-breakPointGetLineNoHash(long lineNo)
+xmlHashTablePtr breakPointGetLineNoHash(long lineNo)
 {
     if (!breakList) {
 #ifdef WITH_XSLDBG_DEBUG_BREAKPOINTS
@@ -191,15 +137,7 @@ breakPointGetLineNoHash(long lineNo)
 }
 
 
-/**
- * breakPointInit:
- *
- * Returns 1 if breakpoints have been initialized properly and all
- *               memory required has been obtained,
- *         0 otherwise
-*/
-int
-breakPointInit(void)
+int breakPointInit(void)
 {
     int result = 0;
 
@@ -214,20 +152,14 @@ breakPointInit(void)
     } else {
 #ifdef WITH_XSLDBG_DEBUG_BREAKPOINTS
         xsltGenericError(xsltGenericErrorContext,
-                         "Unable to intialize breakPoints: memory error\n");
+                         "Unable to initialize breakPoints: memory error\n");
 #endif
     }
     return result;
 }
 
 
-/**
- * breakPointFree:
- *
- * Free all memory used by breakPoints 
- */
-void
-breakPointFree(void)
+void breakPointFree(void)
 {
     if (breakList)
         arrayListFree(breakList);
@@ -235,30 +167,13 @@ breakPointFree(void)
 }
 
 
-/**
- * breakPointEmpty:
- *
- * Empty the break point collection
- *
- * Returns 1 if able to empty the breakpoint list of its contents,
- *         0  otherwise
- */
-int
-breakPointEmpty(void)
+int breakPointEmpty(void)
 {
     return arrayListEmpty(breakList);
 }
 
 
-/** 
- * breakPointItemNew:
- * 
- * Create a new break point item
- * Returns valid break point with default values set if successful, 
- *         NULL otherwise
- */
-breakPointPtr
-breakPointItemNew(void)
+breakPointPtr breakPointItemNew(void)
 {
     breakPointPtr breakPtr = (breakPointPtr) xmlMalloc(sizeof(breakPoint));
 
@@ -275,15 +190,7 @@ breakPointItemNew(void)
 }
 
 
-/**
- * breakPointItemFree:
- * @payload: valid breakPointPtr 
- * @name: not used
- *
- * Free memory associated with this break point
- */
-void
-breakPointItemFree(void *payload, xmlChar * name)
+void breakPointItemFree(void *payload, xmlChar * name)
 {
     Q_UNUSED(name);
     if (payload) {
@@ -300,17 +207,7 @@ breakPointItemFree(void *payload, xmlChar * name)
 }
 
 
-/**
- * breakPointActiveBreakPoint:
- * 
- * Get the active break point
- *
- * Returns The last break point that we stoped at
- *
- * Depreciated
- */
-breakPointPtr
-breakPointActiveBreakPoint(void)
+breakPointPtr breakPointActiveBreakPoint(void)
 {
     /* This function is depreciated */
     return NULL;                /* activeBreakPointItem; */
@@ -318,16 +215,7 @@ breakPointActiveBreakPoint(void)
 
 
 
-/**
- * breakPointSetActiveBreakPoint:
- * @breakPtr: Is valid break point or NULL
- *
- * Set the active break point
- *
- * Depreciated
- */
-void
-breakPointSetActiveBreakPoint(breakPointPtr breakPtr)
+void breakPointSetActiveBreakPoint(breakPointPtr breakPtr)
 {
     Q_UNUSED(breakPtr);
     /*
@@ -337,23 +225,7 @@ breakPointSetActiveBreakPoint(breakPointPtr breakPtr)
 }
 
 
-/**
- * breakPointAdd:
- * @url: Non-null, non-empty file name that has been loaded by
- *                    debugger
- * @lineNumber: @lineNumber >= 0 and is available in url specified and
- *                points to an xml element
- * @templateName: The template name of breakPoint or NULL
- * @modeName : The mode of breakpoint or NULL
- * @type: Valid BreakPointTypeEnum
- *
- * Add break point at file and line number specified
- *
- * Returns 1 if successful,
- *	   0 otherwise
-*/
-int
-breakPointAdd(const xmlChar * url, long lineNumber,
+int breakPointAdd(const xmlChar * url, long lineNumber,
               const xmlChar * templateName, 
 	      const xmlChar * modeName,
 	      BreakPointTypeEnum type)
@@ -478,18 +350,7 @@ breakPointAdd(const xmlChar * url, long lineNumber,
 }
 
 
-/**
- * breakPointDelete:
- * @breakPtr: Is valid
- *
- * Delete the break point specified if it can be found using 
- *    @breakPoint's url and lineNo
- *
- * Returns 1 if successful,
- *	   0 otherwise
-*/
-int
-breakPointDelete(breakPointPtr breakPtr)
+int breakPointDelete(breakPointPtr breakPtr)
 {
     int result = 0;
     xmlHashTablePtr breakPointHash;     /* hash of breakPoints */
@@ -510,18 +371,7 @@ breakPointDelete(breakPointPtr breakPtr)
 }
 
 
-/**
- * breakPointEnable:
- * @breakPtr: A valid breakpoint
- * @enable: Enable break point if 1, disable if 0, toggle if -1
- *
- * Enable or disable a break point
- *
- * Returns 1 if successful,
- *	   0 otherwise
-*/
-int
-breakPointEnable(breakPointPtr breakPtr, int enable)
+int breakPointEnable(breakPointPtr breakPtr, int enable)
 {
     int result = 0;
 
@@ -543,15 +393,7 @@ breakPointEnable(breakPointPtr breakPtr, int enable)
 }
 
 
-/**
- * breakPointLinesCount:
- *
- * Return the number of hash tables of break points with the same line number
- *
- * Returns The number of hash tables of break points with the same line number
- */
-int
-breakPointLinesCount(void)
+int breakPointLinesCount(void)
 {
     if (!breakList) {
 #ifdef WITH_XSLDBG_DEBUG_BREAKPOINTS
@@ -564,32 +406,13 @@ breakPointLinesCount(void)
 }
 
 
-/**
- * breakPointLinesList:
- *
- * Returns The list of hash tables for break points
- *        Dangerous function to use!! 
- */
-arrayListPtr
-breakPointLineList(void)
+arrayListPtr breakPointLineList(void)
 {
     return breakList;
 }
 
 
-/**
- * breakPointGet:
- * @url: Non-null, non-empty file name that has been loaded by
- *                    debugger
- * @lineNumber: lineNumber >= 0 and is available in @url
- *
- * Get a break point for the breakpoint collection
- *
- * Returns break point if break point exists at location specified,
- *	   NULL otherwise
-*/
-breakPointPtr
-breakPointGet(const xmlChar * url, long lineNumber)
+breakPointPtr breakPointGet(const xmlChar * url, long lineNumber)
 {
     xmlHashTablePtr breakHash = breakPointGetLineNoHash(lineNumber);
     breakPointPtr breakPtr = NULL;
@@ -602,17 +425,7 @@ breakPointGet(const xmlChar * url, long lineNumber)
 }
 
 
-/**
- * breakPointPrint:
- * @breakPtr: A valid break point
- *
- * Print the details of @breakPtr
- *
- * Returns 1 if successful,
- *	   0 otherwise
- */
-int
-breakPointPrint(breakPointPtr breakPtr)
+int breakPointPrint(breakPointPtr breakPtr)
 {
     int result = 0;
     const char *breakStatusText[2] = {
@@ -636,26 +449,14 @@ breakPointPrint(breakPointPtr breakPtr)
 
     breakStatus = breakStatusText[breakPtr->flags & BREAKPOINT_ENABLED];
     if (breakPtr->url)
-	xsldbgGenericErrorFunc(i18n("Breakpoint %1 %2 for template: \"%3\" mode: \"%4\" in file \"%5\" at line %6").arg(breakPtr->id).arg(i18n(breakStatus)).arg(xsldbgText(breakTemplate)).arg(xsldbgText(breakMode)).arg(xsldbgUrl(breakPtr->url)).arg(breakPtr->lineNo));
+	xsldbgGenericErrorFunc(ki18n("Breakpoint %1 %2 for template: \"%3\" mode: \"%4\" in file \"%5\" at line %6").subs(breakPtr->id).subs(i18n(breakStatus)).subs(xsldbgText(breakTemplate)).subs(xsldbgText(breakMode)).subs(xsldbgUrl(breakPtr->url)).subs(breakPtr->lineNo).toString());
     else
-	xsldbgGenericErrorFunc(i18n("Breakpoint %1 %2 for template: \"%3\" mode: \"%4\"").arg(breakPtr->id).arg(i18n(breakStatus)).arg(xsldbgText(breakTemplate)).arg(xsldbgText(breakMode)));
+	xsldbgGenericErrorFunc(i18n("Breakpoint %1 %2 for template: \"%3\" mode: \"%4\"", breakPtr->id, i18n(breakStatus), xsldbgText(breakTemplate), xsldbgText(breakMode)));
     return ++result;
 }
 
 
-/**
- * breakPointIsPresent:
- * @url: Non-null, non-empty file name that has been loaded by
- *                    debugger
- * @lineNumber: @lineNumber >= 0 and is available in @url
- *
- * Determine if there is a break point at file and line number specified
- *
- * Returns 1  if successful,  
- *         0 otherwise
-*/
-int
-breakPointIsPresent(const xmlChar * url, long lineNumber)
+int breakPointIsPresent(const xmlChar * url, long lineNumber)
 {
     int result = 0;
 
@@ -668,17 +469,7 @@ breakPointIsPresent(const xmlChar * url, long lineNumber)
 }
 
 
-/**
- * breakPointIsPresentNode:
- * @node: node != NULL
- *
- * Determine if a node is a break point
- *
- * Returns 1 on success, 
- *         0 otherwise
- */
-int
-breakPointIsPresentNode(xmlNodePtr node)
+int breakPointIsPresentNode(xmlNodePtr node)
 {
     int result = 0;
 
